@@ -1,5 +1,6 @@
 import _ from 'lodash';
 import { uiModules } from 'ui/modules';
+import { callAfterBindingsWorkaround } from 'ui/compat';
 import contextSizePickerTemplate from './size_picker.html';
 import './size_picker.less';
 
@@ -10,7 +11,7 @@ const module = uiModules.get('apps/context', [
 module.directive('contextSizePicker', function ContextSizePicker() {
   return {
     bindToController: true,
-    controller: ContextSizePickerController,
+    controller: callAfterBindingsWorkaround(ContextSizePickerController),
     controllerAs: 'contextSizePicker',
     link: linkContextSizePicker,
     replace: true,
