@@ -6,11 +6,11 @@ import { PanelUtils } from './panel/panel_utils';
 import moment from 'moment';
 
 import { stateMonitorFactory } from 'ui/state_management/state_monitor_factory';
-import { createPanelState } from 'plugins/kibana/dashboard/panel/panel_state';
-import { getPersistedStateId } from 'plugins/kibana/dashboard/panel/panel_state';
+import { createPanelState, getPersistedStateId } from 'plugins/kibana/dashboard/panel/panel_state';
 
-function getStateDefaults(dashboard) {
+function getStateDefaults(dashboard, hideWriteControls) {
   return {
+    fullScreenMode: false,
     title: dashboard.title,
     description: dashboard.description,
     timeRestore: dashboard.timeRestore,
@@ -19,7 +19,7 @@ function getStateDefaults(dashboard) {
     uiState: dashboard.uiStateJSON ? JSON.parse(dashboard.uiStateJSON) : {},
     query: FilterUtils.getQueryFilterForDashboard(dashboard),
     filters: FilterUtils.getFilterBarsForDashboard(dashboard),
-    viewMode: dashboard.id ? DashboardViewMode.VIEW : DashboardViewMode.EDIT,
+    viewMode: dashboard.id || hideWriteControls ? DashboardViewMode.VIEW : DashboardViewMode.EDIT,
   };
 }
 
@@ -59,11 +59,13 @@ export class DashboardState {
    *
    * @param savedDashboard {SavedDashboard}
    * @param AppState {AppState}
+   * @param dashboardConfig {DashboardConfigProvider}
    */
-  constructor(savedDashboard, AppState) {
+  constructor(savedDashboard, AppState, dashboardConfig) {
     this.savedDashboard = savedDashboard;
+    this.dashboardConfig = dashboardConfig;
 
-    this.stateDefaults = getStateDefaults(this.savedDashboard);
+    this.stateDefaults = getStateDefaults(this.savedDashboard, this.dashboardConfig.getHideWriteControls());
 
     this.appState = new AppState(this.stateDefaults);
     this.uiState = this.appState.makeStateful('uiState');
@@ -82,6 +84,15 @@ export class DashboardState {
     this.createStateMonitor();
   }
 
+  getFullScreenMode() {
+    return this.appState.fullScreenMode;
+  }
+
+  setFullScreenMode(fullScreenMode) {
+    this.appState.fullScreenMode = fullScreenMode;
+    this.saveState();
+  }
+
   registerPanelIndexPatternMap(panelIndex, indexPattern) {
     if (indexPattern) {
       this.panelIndexPatternMapping[panelIndex] = indexPattern;
@@ -106,12 +117,12 @@ export class DashboardState {
     // The right way to fix this might be to ensure the defaults object stored on state is a deep
     // clone, but given how much code uses the state object, I determined that to be too risky of a change for
     // now.  TODO: revisit this!
-    this.stateDefaults = getStateDefaults(this.savedDashboard);
+    this.stateDefaults = getStateDefaults(this.savedDashboard, this.dashboardConfig.getHideWriteControls());
     // The original query won't be restored by the above because the query on this.savedDashboard is applied
     // in place in order for it to affect the visualizations.
     this.stateDefaults.query = this.lastSavedDashboardFilters.query;
     // Need to make a copy to ensure they are not overwritten.
-    this.stateDefaults.filters = Object.assign(new Array(), this.getLastSavedFilterBars());
+    this.stateDefaults.filters = [...this.getLastSavedFilterBars()];
 
     this.isDirty = false;
     this.appState.setDefaults(this.stateDefaults);
@@ -208,7 +219,19 @@ export class DashboardState {
    * new dashboard, if the query differs from the default.
    */
   getQueryChanged() {
-    return !_.isEqual(this.appState.query, this.getLastSavedQuery());
+    const currentQuery = this.appState.query;
+    const lastSavedQuery = this.getLastSavedQuery();
+
+    const isLegacyStringQuery = (
+      _.isString(lastSavedQuery)
+      && _.isPlainObject(currentQuery)
+      && _.has(currentQuery, 'query')
+    );
+    if (isLegacyStringQuery) {
+      return lastSavedQuery !== currentQuery.query;
+    }
+
+    return !_.isEqual(currentQuery, lastSavedQuery);
   }
 
   /**
@@ -236,7 +259,7 @@ export class DashboardState {
    * @returns {DashboardViewMode}
    */
   getViewMode() {
-    return this.appState.viewMode;
+    return this.dashboardConfig.getHideWriteControls() ? DashboardViewMode.VIEW : this.appState.viewMode;
   }
 
   /**
@@ -393,14 +416,8 @@ export class DashboardState {
    */
   applyFilters(query, filters) {
     this.appState.query = query;
-    if (this.appState.query) {
-      this.savedDashboard.searchSource.set('filter', _.union(filters, [{
-        query: this.appState.query
-      }]));
-    } else {
-      this.savedDashboard.searchSource.set('filter', filters);
-    }
-
+    this.savedDashboard.searchSource.set('query', query);
+    this.savedDashboard.searchSource.set('filter', filters);
     this.saveState();
   }
 
@@ -413,6 +430,8 @@ export class DashboardState {
     this.stateMonitor.ignoreProps('viewMode');
     // Filters need to be compared manually because they sometimes have a $$hashkey stored on the object.
     this.stateMonitor.ignoreProps('filters');
+    // Query needs to be compared manually because saved legacy queries get migrated in app state automatically
+    this.stateMonitor.ignoreProps('query');
 
     this.stateMonitor.onChange(status => {
       this.isDirty = status.dirty;
