@@ -9,7 +9,10 @@ function Agg(props) {
   if (!Component) {
     Component = StdAgg;
   }
-  const style = Object.assign({ cursor: 'default' }, props.style);
+  const style = {
+    cursor: 'default',
+    ...props.style
+  };
   return (
     <div
       className={props.className}
