@@ -2,48 +2,45 @@ import { uiModules } from 'ui/modules';
 import 'plugins/kbn_vislib_vis_types/controls/vislib_basic_options';
 import _ from 'lodash';
 import AggConfigResult from 'ui/vis/agg_config_result';
-import { KibanaMap } from 'ui/vis_maps/kibana_map';
+import { KibanaMap } from '../../tile_map/public/kibana_map';
 import ChoroplethLayer from './choropleth_layer';
 import { truncatedColorMaps }  from 'ui/vislib/components/color/truncated_colormaps';
 import AggResponsePointSeriesTooltipFormatterProvider from './tooltip_formatter';
-import { ResizeCheckerProvider } from 'ui/resize_checker';
-import 'ui/vis_maps/lib/service_settings';
+import 'ui/vis/map/service_settings';
 
 
 const module = uiModules.get('kibana/region_map', ['kibana']);
 module.controller('KbnRegionMapController', function ($scope, $element, Private, Notifier, getAppState,
                                                        serviceSettings, config) {
 
+  const DEFAULT_ZOOM_SETTINGS = {
+    zoom: 2,
+    mapCenter: [0, 0]
+  };
+
   const tooltipFormatter = Private(AggResponsePointSeriesTooltipFormatterProvider);
-  const ResizeChecker = Private(ResizeCheckerProvider);
   const notify = new Notifier({ location: 'Region map' });
-  const resizeChecker = new ResizeChecker($element);
 
   let kibanaMap = null;
-  resizeChecker.on('resize', () => {
+  let choroplethLayer = null;
+  const kibanaMapReady = makeKibanaMap();
+
+  $scope.$watch('resize', () => {
     if (kibanaMap) {
       kibanaMap.resize();
     }
   });
-  let choroplethLayer = null;
-  const kibanaMapReady = makeKibanaMap();
 
-  $scope.$watch('esResponse', async function (response) {
+  $scope.$watch('esResponse', async function (tableGroup) {
+
     kibanaMapReady.then(() => {
-      const metricsAgg = _.first($scope.vis.aggs.bySchemaName.metric);
-      const termAggId = _.first(_.pluck($scope.vis.aggs.bySchemaName.segment, 'id'));
 
       let results;
-      if (!response || !response.aggregations) {
+      if (!tableGroup || !tableGroup.tables || !tableGroup.tables.length || tableGroup.tables[0].columns.length !== 2) {
         results = [];
       } else {
-        const buckets = response.aggregations[termAggId].buckets;
-        results = buckets.map((bucket) => {
-          return {
-            term: bucket.key,
-            value: metricsAgg.getValue(bucket)
-          };
-        });
+        const buckets = tableGroup.tables[0].rows;
+        results = buckets.map(([term, value]) => { return { term: term, value: value }; });
       }
 
       if (!$scope.vis.params.selectedJoinField && $scope.vis.params.selectedLayer) {
@@ -55,6 +52,8 @@ module.controller('KbnRegionMapController', function ($scope, $element, Private,
       }
 
       updateChoroplethLayer($scope.vis.params.selectedLayer.url, $scope.vis.params.selectedLayer.attribution);
+
+      const metricsAgg = _.first($scope.vis.getAggConfig().bySchemaName.metric);
       choroplethLayer.setMetrics(results, metricsAgg);
       setTooltipFormatter();
 
@@ -90,19 +89,28 @@ module.controller('KbnRegionMapController', function ($scope, $element, Private,
   async function makeKibanaMap() {
     const tmsSettings = await serviceSettings.getTMSService();
     const minMaxZoom = tmsSettings.getMinMaxZoom(false);
-    kibanaMap = new KibanaMap($element[0], minMaxZoom);
-    const url = tmsSettings.getUrl();
-    const options = tmsSettings.getTMSOptions();
-    kibanaMap.setBaseLayer({ baseLayerType: 'tms', options: { url, ...options } });
+
+    const options = { ...minMaxZoom };
+    const uiState = $scope.vis.getUiState();
+    const zoomFromUiState = parseInt(uiState.get('mapZoom'));
+    const centerFromUIState = uiState.get('mapCenter');
+    options.zoom = !isNaN(zoomFromUiState) ? zoomFromUiState : DEFAULT_ZOOM_SETTINGS.zoom;
+    options.center = centerFromUIState ? centerFromUIState : DEFAULT_ZOOM_SETTINGS.mapCenter;
+    kibanaMap = new KibanaMap($element[0], options);
+
+
+    const tmsUrl = tmsSettings.getUrl();
+    const tmsOptions = tmsSettings.getTMSOptions();
+    kibanaMap.setBaseLayer({ baseLayerType: 'tms', options: { tmsUrl, ...tmsOptions } });
     kibanaMap.addLegendControl();
     kibanaMap.addFitControl();
     kibanaMap.persistUiStateForVisualization($scope.vis);
   }
 
   function setTooltipFormatter() {
-    const metricsAgg = _.first($scope.vis.aggs.bySchemaName.metric);
-    if ($scope.vis.aggs.bySchemaName.segment && $scope.vis.aggs.bySchemaName.segment[0]) {
-      const fieldName = $scope.vis.aggs.bySchemaName.segment[0].makeLabel();
+    const metricsAgg = _.first($scope.vis.getAggConfig().bySchemaName.metric);
+    if ($scope.vis.getAggConfig().bySchemaName.segment && $scope.vis.getAggConfig().bySchemaName.segment[0]) {
+      const fieldName = $scope.vis.getAggConfig().bySchemaName.segment[0].makeLabel();
       choroplethLayer.setTooltipFormatter(tooltipFormatter, metricsAgg, fieldName);
     } else {
       choroplethLayer.setTooltipFormatter(tooltipFormatter, metricsAgg, null);
@@ -123,9 +131,9 @@ module.controller('KbnRegionMapController', function ($scope, $element, Private,
       choroplethLayer.setMetrics(previousMetrics, previousMetricsAgg);
     }
     choroplethLayer.on('select', function (event) {
-      const aggs = $scope.vis.aggs.getResponseAggs();
+      const aggs = $scope.vis.getAggConfig().getResponseAggs();
       const aggConfigResult = new AggConfigResult(aggs[0], false, event, event);
-      $scope.vis.listeners.click({ point: { aggConfigResult: aggConfigResult } });
+      $scope.vis.API.events.filter({ point: { aggConfigResult: aggConfigResult } });
     });
     choroplethLayer.on('styleChanged', function (event) {
       if (event.mismatches.length > 0 && config.get('visualization:regionmap:showWarnings')) {
