@@ -1,12 +1,9 @@
-import _ from 'lodash';
-
 export function PointSeriesInitYAxisProvider() {
 
   return function initYAxis(chart) {
     const y = chart.aspects.y;
-    const x = chart.aspects.x;
 
-    if (_.isArray(y)) {
+    if (Array.isArray(y)) {
       // TODO: vis option should allow choosing this format
       chart.yAxisFormatter = y[0].agg.fieldFormatter();
       chart.yAxisLabel = ''; // use the legend
@@ -17,7 +14,7 @@ export function PointSeriesInitYAxisProvider() {
 
     const z = chart.aspects.series;
     if (z) {
-      if (_.isArray(z)) {
+      if (Array.isArray(z)) {
         chart.zAxisFormatter = z[0].agg.fieldFormatter();
         chart.zAxisLabel = ''; // use the legend
       } else {
@@ -25,9 +22,5 @@ export function PointSeriesInitYAxisProvider() {
         chart.zAxisLabel = z.col.title;
       }
     }
-
-
-    const xAggOutput = x.agg.write();
-    chart.yScale = xAggOutput.metricScale || null;
   };
 }
