@@ -1,6 +1,7 @@
 import testSubjSelector from '@elastic/test-subj-selector';
 
-module.exports = function bindToJquery($) {
+// eslint-disable-next-line kibana-custom/no-default-export
+export default function bindToJquery($) {
 
   /**
    * Find elements with the `data-test-subj` attribute by the terms in that attribute.
@@ -54,4 +55,4 @@ module.exports = function bindToJquery($) {
     return $els;
   }
 
-};
+}
