@@ -25,7 +25,14 @@ export function formatMsg(err, from) {
     rtn += formatMsg.describeError(err);
   } else if (has(err, 'status') && has(err, 'data')) {
     // is an Angular $http "error object"
-    rtn += 'Error ' + err.status + ' ' + err.statusText + ': ' + err.data.message;
+    if (err.status === -1) {
+      // status = -1 indicates that the request was failed to reach the server
+      rtn += 'An HTTP request has failed to connect. ' +
+             'Please check if the Kibana server is running and that your browser has a working connection, ' +
+             'or contact your system administrator.';
+    } else {
+      rtn += 'Error ' + err.status + ' ' + err.statusText + ': ' + err.data.message;
+    }
   }
 
   return rtn;
@@ -37,4 +44,3 @@ formatMsg.describeError = function (err) {
   if (err.message) return err.message;
   return '' + err;
 };
-
